package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysUnitConvert;
import com.ruoyi.system.service.ISysUnitConvertService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 单位换算Controller
 * 
 * @author ruoyi
 * @date 2025-02-09
 */
@RestController
@RequestMapping("/system/sysUnitConvert")
public class SysUnitConvertController extends BaseController
{
    @Autowired
    private ISysUnitConvertService sysUnitConvertService;

    /**
     * 查询单位换算列表
     */
    @PreAuthorize("@ss.hasPermi('system:sysUnitConvert:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysUnitConvert sysUnitConvert)
    {
        startPage();
        List<SysUnitConvert> list = sysUnitConvertService.selectSysUnitConvertList(sysUnitConvert);
       TableDataInfo tableDataInfo=getDataTable(list);
        return tableDataInfo;
    }

    /**
     * 导出单位换算列表
     */
    @PreAuthorize("@ss.hasPermi('system:sysUnitConvert:export')")
    @Log(title = "单位换算", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysUnitConvert sysUnitConvert)
    {
        List<SysUnitConvert> list = sysUnitConvertService.selectSysUnitConvertList(sysUnitConvert);
        ExcelUtil<SysUnitConvert> util = new ExcelUtil<SysUnitConvert>(SysUnitConvert.class);
        util.exportExcel(response, list, "单位换算数据");
    }

    /**
     * 获取单位换算详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:sysUnitConvert:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sysUnitConvertService.selectSysUnitConvertById(id));
    }

    /**
     * 新增单位换算
     */
    @PreAuthorize("@ss.hasPermi('system:sysUnitConvert:add')")
    @Log(title = "单位换算", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysUnitConvert sysUnitConvert)
    {
        return toAjax(sysUnitConvertService.insertSysUnitConvert(sysUnitConvert));
    }

    /**
     * 修改单位换算
     */
    @PreAuthorize("@ss.hasPermi('system:sysUnitConvert:edit')")
    @Log(title = "单位换算", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysUnitConvert sysUnitConvert)
    {
        return toAjax(sysUnitConvertService.updateSysUnitConvert(sysUnitConvert));
    }

    /**
     * 删除单位换算
     */
    @PreAuthorize("@ss.hasPermi('system:sysUnitConvert:remove')")
    @Log(title = "单位换算", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysUnitConvertService.deleteSysUnitConvertByIds(ids));
    }
}
